package com.grupo.proyectoescuela.controlador;

import com.grupo.proyectoescuela.modelo.Estudiante;
import com.grupo.proyectoescuela.servicio.EstudianteServicio;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * Controlador REST para la entidad Estudiante.
 * Proporciona operaciones CRUD a través de una API RESTful.
 */
@RestController
@RequestMapping("/estudiantes")
public class EstudianteControlador {

    /**
     * Servicio para realizar operaciones sobre los estudiantes.
     */
    private final EstudianteServicio estudianteServicio;

    /**
     * Constructor para inyección de dependencias.
     *
     * @param estudianteServicio servicio de estudiantes
     */
    @Autowired
    public EstudianteControlador(EstudianteServicio estudianteServicio) {
        this.estudianteServicio = estudianteServicio;
    }

    /**
     * Obtiene la lista de todos los estudiantes.
     *
     * @return lista de estudiantes
     */
    @GetMapping
    public List<Estudiante> obtenerTodosLosEstudiantes() {
        return estudianteServicio.obtenerTodosLosEstudiantes();
    }

    /**
     * Obtiene un estudiante específico por su ID.
     *
     * @param id identificador del estudiante
     * @return el estudiante correspondiente al ID proporcionado
     */
    @GetMapping("/{id}")
    public Estudiante obtenerEstudiantePorId(@PathVariable Long id) {
        return estudianteServicio.obtenerEstudiantePorId(id);
    }

    /**
     * Crea un nuevo estudiante.
     *
     * @param estudiante objeto estudiante para ser creado
     * @return el estudiante creado
     */
    @PostMapping
    public Estudiante crearEstudiante(@RequestBody Estudiante estudiante) {
        return estudianteServicio.guardarEstudiante(estudiante);
    }

    /**
     * Actualiza la información de un estudiante existente.
     *
     * @param id identificador del estudiante a actualizar
     * @param estudiante objeto estudiante con los datos actualizados
     * @return el estudiante actualizado
     */
    @PutMapping("/{id}")
    public Estudiante actualizarEstudiante(@PathVariable Long id, @RequestBody Estudiante estudiante) {
        estudiante.setId(id);
        return estudianteServicio.guardarEstudiante(estudiante);
    }

    /**
     * Elimina un estudiante por su ID.
     *
     * @param id identificador del estudiante a eliminar
     */
    @DeleteMapping("/{id}")
    public void eliminarEstudiante(@PathVariable Long id) {
        estudianteServicio.eliminarEstudiante(id);
    }
}
