package com.grupo.proyectoescuela.controlador;

import com.grupo.proyectoescuela.modelo.Nota;
import com.grupo.proyectoescuela.servicio.NotaServicio;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * Controlador REST para la entidad Nota.
 * Proporciona operaciones CRUD a través de una API RESTful.
 */
@RestController
@RequestMapping("/notas")
public class NotaControlador {

    /**
     * Servicio para realizar operaciones sobre las notas.
     */
    private final NotaServicio notaServicio;

    /**
     * Constructor para inyección de dependencias.
     *
     * @param notaServicio servicio de notas
     */
    @Autowired
    public NotaControlador(NotaServicio notaServicio) {
        this.notaServicio = notaServicio;
    }

    /**
     * Obtiene la lista de todas las notas.
     *
     * @return lista de notas
     */
    @GetMapping
    public List<Nota> obtenerTodasLasNotas() {
        return notaServicio.obtenerTodasLasNotas();
    }

    /**
     * Obtiene una nota específica por su ID.
     *
     * @param id identificador de la nota
     * @return la nota correspondiente al ID proporcionado
     */
    @GetMapping("/{id}")
    public Nota obtenerNotaPorId(@PathVariable Long id) {
        return notaServicio.obtenerNotaPorId(id);
    }

    /**
     * Crea una nueva nota.
     *
     * @param nota objeto nota para ser creada
     * @return la nota creada
     */
    @PostMapping
    public Nota crearNota(@RequestBody Nota nota) {
        return notaServicio.guardarNota(nota);
    }

    /**
     * Actualiza la información de una nota existente.
     *
     * @param id identificador de la nota a actualizar
     * @param nota objeto nota con los datos actualizados
     * @return la nota actualizada
     */
    @PutMapping("/{id}")
    public Nota actualizarNota(@PathVariable Long id, @RequestBody Nota nota) {
        nota.setId(id);
        return notaServicio.guardarNota(nota);
    }

    /**
     * Elimina una nota por su ID.
     *
     * @param id identificador de la nota a eliminar
     */
    @DeleteMapping("/{id}")
    public void eliminarNota(@PathVariable Long id) {
        notaServicio.eliminarNota(id);
    }
}
