package com.grupo.proyectoescuela.servicio;

import com.grupo.proyectoescuela.modelo.Estudiante;
import com.grupo.proyectoescuela.modelo.Nota;
import com.grupo.proyectoescuela.repositorio.EstudianteRepositorio;
import com.grupo.proyectoescuela.repositorio.NotaRepositorio;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * Servicio para manejar las operaciones relacionadas con los estudiantes.
 * Proporciona métodos para obtener, guardar y eliminar estudiantes.
 */
@Service
public class EstudianteServicio {

    private final EstudianteRepositorio estudianteRepositorio;
    private final NotaRepositorio notaRepositorio;

    /**
     * Constructor con inyección de dependencias para los repositorios necesarios.
     *
     * @param estudianteRepositorio repositorio para manejar operaciones relacionadas con los estudiantes
     * @param notaRepositorio repositorio para manejar operaciones relacionadas con las notas
     */
    @Autowired
    public EstudianteServicio(EstudianteRepositorio estudianteRepositorio, NotaRepositorio notaRepositorio) {
        this.estudianteRepositorio = estudianteRepositorio;
        this.notaRepositorio = notaRepositorio;
    }

    /**
     * Método para obtener todos los estudiantes.
     *
     * @return una lista de todos los estudiantes
     */
    public List<Estudiante> obtenerTodosLosEstudiantes() {
        return estudianteRepositorio.findAll();
    }

    /**
     * Método para obtener un estudiante por su id.
     *
     * @param id el id del estudiante
     * @return el estudiante si se encuentra, o null si no se encuentra
     */
    public Estudiante obtenerEstudiantePorId(Long id) {
        return estudianteRepositorio.findById(id).orElse(null);
    }

    /**
     * Método para guardar un estudiante.
     *
     * @param estudiante el estudiante a guardar
     * @return el estudiante guardado
     */
    public Estudiante guardarEstudiante(Estudiante estudiante) {
        return estudianteRepositorio.save(estudiante);
    }

    /**
     * Método para eliminar un estudiante por su id.
     * Antes de eliminar el estudiante, también elimina todas las notas asociadas con ese estudiante.
     *
     * @param id el id del estudiante a eliminar
     */
    public void eliminarEstudiante(Long id) {
        Estudiante estudiante = estudianteRepositorio.findById(id).orElse(null);
        if (estudiante != null) {
            List<Nota> notas = notaRepositorio.findByEstudiante(estudiante);
            notas.forEach(nota -> notaRepositorio.deleteById(nota.getId()));
            estudianteRepositorio.deleteById(id);
        }
    }
}
