/**
 * La clase ApiRequest facilita las solicitudes HTTP POST y GET al API.
 * Utiliza la biblioteca Unirest para manejar las solicitudes HTTP.
 */
package com.grupo.proyectoescuela.util;

import kong.unirest.HttpResponse;
import kong.unirest.JsonNode;
import kong.unirest.Unirest;
import kong.unirest.json.JSONArray;
import kong.unirest.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

public class ApiRequest {

    /**
     * Realiza una solicitud POST a la URL proporcionada con el cuerpo de la solicitud dado.
     * Convierte el objeto del cuerpo de la solicitud a JSON antes de enviarlo.
     *
     * @param url        La URL del recurso al que se debe realizar la solicitud.
     * @param requestBody El cuerpo de la solicitud a enviar, se convertirá a JSON.
     * @param <T>        El tipo de objeto del cuerpo de la solicitud.
     */
    public <T> void postRequest(String url, T requestBody) {
        HttpResponse<JsonNode> response = Unirest.post(url)
                .header("Content-Type", "application/json")
                .body(requestBody)
                .asJson();
    }

    /**
     * Realiza una solicitud GET a la URL proporcionada y convierte la respuesta en una lista de objetos del tipo especificado.
     *
     * @param url           La URL del recurso al que se debe realizar la solicitud.
     * @param responseType  El tipo de objeto en el que se debe convertir la respuesta. 
     * @param <T>           El tipo de objeto en la respuesta.
     * @return              Una lista de objetos del tipo especificado que representan la respuesta a la solicitud GET.
     */
    public <T> List<T> getRequest(String url, Class<T> responseType) {
        HttpResponse<JsonNode> response = Unirest.get(url)
                .header("Accept", "application/json")
                .asJson();
        JSONArray array = response.getBody().getArray();
        List<T> list = new ArrayList<>();
        for (int i = 0; i < array.length(); i++) {
            JSONObject object = array.getJSONObject(i);
            T item = Unirest.config().getObjectMapper().readValue(object.toString(), responseType);
            list.add(item);
        }
        return list;
    }
}
